pub enum ErrorKind {
ActorGone,
ReplyErr,
MailboxFull,
Timeout,
}Expand description
Kinds of errors that may occur while running the runtime.
Variants
ActorGone
An actor that was expected to be available was unreachable, probably because it either panicked or exited. It’s unlikely this operation can be retried successfully.
ReplyErr
The actor replied with an error.
MailboxFull
The target actor’s mailbox was full.
Timeout
An operation timed out.