pub struct PeerByAcceptedRoute {
pub ip: IpAddr,
}Expand description
Lookup all peers that accept packets addressed to the given IP.
This includes the peer’s tailnet address and any subnet routes it provides. Only
the peers with the most specific subnet route match that covers ip will be
returned.
E.g., suppose:
- We’re querying for
10.1.2.3 PeerAandPeerBhave accepted routes for10.1.2.0/24PeerChas an accepted route for10.1.0.0/16
Only PeerA and PeerB will be returned, since they have the most specific
prefix match.
Fields
ip: IpAddrTrait Implementations
Sourceimpl Message<PeerByAcceptedRoute> for PeerTracker
impl Message<PeerByAcceptedRoute> for PeerTracker