Task

Struct Task 

pub struct Task<Fut>(/* private fields */);
An actor that runs a future and is associated bidirectionally with its lifecycle: the actor dying stops the task, and the task dying kills the actor.

To support background tasks, Task holds its own ActorRef – it doesn’t die if you don’t hold a reference to it.

Kameo doesn’t natively provide functionality for this – ActorRef::attach_stream is the closest thing, but it doesn’t fit the mental model of a background task that doesn’t necessarily produce messages. So instead this is a thin wrapper around tokio::spawn, and the inner future kills the actor if the future completes.

Task implements Message<Infallible> so it can be addressed as a type-erased Recipient even though it doesn’t accept any messages.

If you need to be generic over the task future or would need to name the type of an anonymous future, it’s recommended to box the future and use ErasedTask as the task type.

Examples

Spawning a task that shares lifecycle with a parent:

struct Parent;

impl Actor for Parent {
    type Error = ();
    type Args = ();

    async fn on_start(_: (), slf: ActorRef<Self>) -> Result<Self, ()> {
        Task::spawn_link(&slf, async move {
            for i in 0.. {
                println!("{i}");
                tokio::time::sleep(Duration::from_millis(25)).await;
            }
        });

        // ... other self-init ...

        Ok(Self)
    }
}

let parent = Parent::spawn(());
tokio::time::sleep(Duration::from_millis(99)).await;
parent.kill();
// prints 0, 1, 2, 3, then the parent and task are killed