pub enum ErrorKind {
ActorGone,
ReplyErr,
MailboxFull,
Timeout,
UnsupportedInTunMode,
TunUnavailable,
NetworkMonitorUnavailable,
}Expand description
Kinds of errors that may occur while running the runtime.
Variants
ActorGone
An actor that was expected to be available was unreachable, probably because it either panicked or exited. It’s unlikely this operation can be retried successfully.
ReplyErr
The actor replied with an error.
MailboxFull
The target actor’s mailbox was full.
Timeout
An operation timed out.
UnsupportedInTunMode
A netstack-only operation was attempted on a runtime running in TUN transport mode (no userspace application netstack exists in that mode).
TUN transport mode was requested but the TUN device could not be created (e.g. missing
root/CAP_NET_ADMIN), or the runtime was built without the tun feature.
The network monitor was requested (Config::network_monitor == true) but the runtime was
built without the network-monitor feature, so the supervisor could not be spawned. A
config/build mismatch knowable at spawn time; never silently ignored (mirrors
TunUnavailable).