Peer delta update tracking.
Structs
- GetStatus
- Build the peer entries of a
Statussnapshot. - Peer
ByAccepted Route - Lookup all peers that accept packets addressed to the given IP.
- Peer
ByName - Lookup a peer by name.
- Peer
ByTailnet Ip - Lookup the peer that has the given tailnet IP address.
- PeerDb
- A database that stores a map of peers by
PeerIdand multiple indices. - Peer
Tracker - Actor that tracks peer delta updates and emits new states.
- Republish
State - Ask the peer tracker to re-broadcast its current peer snapshot on the bus, without any peer
change.
Device::set_exit_nodesends this after changing the exit-node selector so the route updater and source filter (bothArc<PeerState>subscribers) re-resolve the new selector immediately, rather than waiting for the next netmap update. - Watch
Netmap - Subscribe to netmap peer-change events.
- Whois
- Resolve which node owns a tailnet source address.