pub struct PeerDb { /* private fields */ }Expand description
A database that stores a map of peers by PeerId and multiple indices.
Assumes that all indexed fields are unique per-node, with a few notable exceptions:
- Hostname may be duplicated, though the fqdn (including the tailnet component) may not be.
- Accepted routes may overlap.
Implementations
Sourceimpl PeerDb
impl PeerDb
Sourcepub fn upsert(&mut self, new: &Node) -> PeerId
pub fn upsert(&mut self, new: &Node) -> PeerId
Upsert a node into the peer db.
The StableNodeId is used as the primary key to identify the node.
Sourcepub fn remove(&mut self, field: &dyn IndexedField) -> Option<(PeerId, Node)>
pub fn remove(&mut self, field: &dyn IndexedField) -> Option<(PeerId, Node)>
Remove a peer by a given indexed field.
Sourcepub fn get(&self, field: &dyn IndexedField) -> Option<(PeerId, &Node)>
pub fn get(&self, field: &dyn IndexedField) -> Option<(PeerId, &Node)>
Get the node with the given field.
Sourcepub fn get_route(&self, route: IpNet) -> impl Iterator<Item = (PeerId, &Node)>
pub fn get_route(&self, route: IpNet) -> impl Iterator<Item = (PeerId, &Node)>
Get the nodes with the closest matching route.