Runtime

Struct Runtime 

pub struct Runtime {
    pub control: ActorRef<ControlRunner>,
    pub peer_tracker: WeakActorRef<PeerTracker>,
    /* private fields */
}
The runtime for a tailscale device.

Fields

control: ActorRef<ControlRunner>

Reference to the control actor.

peer_tracker: WeakActorRef<PeerTracker>

Reference to the peer tracker for peer lookups.

Implementations

Source

impl Runtime

pub async fn spawn( config: Config, auth_key: Option<String>, keys: NodeState, ) -> Result<Self, Error>

Spawn a new runtime with the given parameters for connecting to a tailnet.

pub async fn channel(&self) -> Result<Channel, Error>

Get a channel to send commands to the netstack.

pub async fn graceful_shutdown(self, timeout: Option<Duration>) -> bool

Attempt to shut down the runtime gracefully.

Returns false if the shutdown timed out. It is still shut down if it timed out, just more violently and with possible resource leaks.